==> laravel-scripts-0.1.36.tgz: package/tasks/tpl.js <==
// @ts-check

/**
 * Clean compiled template files location
 */
function tplClean() {
  const del = require("del");
  const paths = require("../paths");
  return del(paths.join(paths.frontend.dest.base, "**/*"));
}

/**
 * Build only template files ( blade templates and php)
 */
function tplBuild(callback) {
  const gulp = require("gulp");
  const coreSync = require("./coreSync");
  const tplComponents = require("./tplComponents");
  const tplFragments = require("./tplFragments");
  const tplLaravel = require("./tplLaravel");
  const tplLayouts = require("./tplLayouts");
  const tplRoutes = require("./tplRoutes");
  const tplUtils = require("./tplUtils");

  return gulp.parallel([
    coreSync,
    tplComponents,
    tplFragments,
    tplLaravel,
    tplLayouts,
    tplRoutes,
    tplUtils,
  ])(callback);
}

/**
 * Watch only template files ( blade templates and php)
 */
function tplWatch(callback) {
  const gulp = require("gulp");
  const paths = require("../paths");
  const { getWatchPath } = require("../utils");
  const tplComponents = require("./tplComponents");
  const tplFragments = require("./tplFragments");
  // const tplLaravel = require("./tplLaravel");
  const tplLayouts = require("./tplLayouts");
  const tplRoutes = require("./tplRoutes");
  const tplUtils = require("./tplUtils");
  const { clear } = require("./clean");
  const { join, frontend } = paths;
  const { src } = frontend;

  gulp.watch(
    getWatchPath(join(src.components, "/**/*.blade.php")),
    tplComponents
  );
  // changes to php component class files require a clearing of laravel cache
  gulp.watch(
    getWatchPath(join(src.components, "/**/*!(.blade).php")),
    gulp.series(tplComponents, clear)
  );
  gulp.watch(getWatchPath(join(src.fragments, "/**/*.php")), tplFragments);
  gulp.watch(getWatchPath(join(src.layouts, "/**/*.php")), tplLayouts);
  gulp.watch(getWatchPath(join(src.utils, "/**/*.php")), tplUtils);
  gulp.watch(getWatchPath(join(src.routes, "/**/*.{php,json}")), tplRoutes);
}

/**
 * Exposse build and watch task separetely
 */
module.exports = {
  tplClean,
  tplBuild,
  tplWatch,
};

==> laravel-scripts-0.1.37.tgz: package/tasks/tpl.js <==
// @ts-check

/**
 * Clean compiled template files location
 */
function tplClean() {
  const del = require("del");
  const paths = require("../paths");
  return del(paths.join(paths.frontend.dest.base, "**/*"));
}

/**
 * Build only template files ( blade templates and php)
 */
function tplBuild(callback) {
  const gulp = require("gulp");
  const coreSync = require("./coreSync");
  const tplComponents = require("./tplComponents");
  const tplFragments = require("./tplFragments");
  const tplLaravel = require("./tplLaravel");
  const tplLayouts = require("./tplLayouts");
  const tplRoutes = require("./tplRoutes");
  const tplUtils = require("./tplUtils");

  return gulp.parallel([
    coreSync,
    tplComponents,
    tplFragments,
    tplLaravel,
    tplLayouts,
    tplRoutes,
    tplUtils,
  ])(callback);
}

/**
 * Watch only template files ( blade templates and php)
 */
function tplWatch(callback) {
  const gulp = require("gulp");
  const paths = require("../paths");
  const { getWatchPath } = require("../utils");
  const tplComponents = require("./tplComponents");
  const tplFragments = require("./tplFragments");
  // const tplLaravel = require("./tplLaravel");
  const tplLayouts = require("./tplLayouts");
  const tplRoutes = require("./tplRoutes");
  const tplUtils = require("./tplUtils");
  const { clear } = require("./clean");
  const { join, frontend } = paths;
  const { src } = frontend;

  gulp.watch(
    getWatchPath(join(src.components, "/**/*.blade.php")),
    tplComponents
  );
  // changes to php component class files require a clearing of laravel cache
  gulp.watch(
    getWatchPath(join(src.components, "/**/*!(.blade).php")),
    gulp.series(tplComponents, clear)
  );
  gulp.watch(getWatchPath(join(src.fragments, "/**/*.php")), tplFragments);
  gulp.watch(getWatchPath(join(src.layouts, "/**/*.php")), tplLayouts);
  gulp.watch(getWatchPath(join(src.utils, "/**/*.php")), tplUtils);
  gulp.watch(getWatchPath(join(src.routes, "/**/*.blade.php")), tplRoutes);
  gulp.watch(getWatchPath(join(src.routes, "/**/*.json")), tplRoutes);
  // changes to php route class files require a clearing of laravel cache
  gulp.watch(
    getWatchPath(join(src.components, "/**/*!(.blade).php")),
    gulp.series(tplRoutes, clear)
  );
}

/**
 * Exposse build and watch task separetely
 */
module.exports = {
  tplClean,
  tplBuild,
  tplWatch,
};
